from setuptools import setup, find_packages

setup(
    name = "pulsewidth",
    version = "1.0.3",
    description="Useful to get coordinates with slopes above a certain threshold value",
    url='https://github.com/Astrojigs/pulsewidth',
    license="MIT",
	packages=find_packages(),
    authors='Jigar and Pratik'

)
